@@ -6,7 +6,7 @@ rmvnormmix <- normmixrm.sim <- function(n,lambda=1,mu=0,sigma=1) {
   if ((r <- NCOL(mu)) != NCOL(sigma)) {
     stop("mu and sigma must have the same number of columns", call.=FALSE)
   }
-  z <- sample(m,n,rep=TRUE,prob=lambda) # component 
+  z <- sample(m,n,replace=TRUE,prob=lambda) # component 
   matrix(rnorm(n*r,mean=as.vector(mu[z,]),sd=as.vector(sigma[z,])),n,r)  
 }
 
